@@ -12,16 +12,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six.moves.urllib.parse as urlparse
-
 from django.conf import settings
-from django.core import urlresolvers
 from django.template import defaultfilters as d_filters
+from django import urls
 
 from django.utils.translation import pgettext_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
+import six
+import six.moves.urllib.parse as urlparse
+
 from horizon import exceptions
 from horizon import messages
 from horizon import tables
@@ -83,9 +84,9 @@ class RestartInstance(tables.BatchAction):
     classes = ('btn-danger', 'btn-reboot')
 
     def allowed(self, request, instance=None):
-        return ((instance.status in ACTIVE_STATES
-                 or instance.status == 'SHUTDOWN'
-                 or instance.status == 'RESTART_REQUIRED'))
+        return ((instance.status in ACTIVE_STATES or
+                 instance.status == 'SHUTDOWN' or
+                 instance.status == 'RESTART_REQUIRED'))
 
     def action(self, request, obj_id):
         api.trove.instance_restart(request, obj_id)
@@ -112,8 +113,8 @@ class DetachReplica(tables.BatchAction):
     classes = ('btn-danger', 'btn-detach-replica')
 
     def allowed(self, request, instance=None):
-        return (instance.status in ACTIVE_STATES
-                and hasattr(instance, 'replica_of'))
+        return (instance.status in ACTIVE_STATES and
+                hasattr(instance, 'replica_of'))
 
     def action(self, request, obj_id):
         api.trove.instance_detach_replica(request, obj_id)
@@ -126,12 +127,12 @@ class PromoteToReplicaSource(tables.LinkAction):
     classes = ("ajax-modal", "btn-promote-to-replica-source")
 
     def allowed(self, request, instance=None):
-        return (instance.status in ACTIVE_STATES
-                and hasattr(instance, 'replica_of'))
+        return (instance.status in ACTIVE_STATES and
+                hasattr(instance, 'replica_of'))
 
     def get_link_url(self, datum):
         instance_id = self.table.get_object_id(datum)
-        return urlresolvers.reverse(self.url, args=[instance_id])
+        return urls.reverse(self.url, args=[instance_id])
 
 
 class EjectReplicaSource(tables.BatchAction):
@@ -155,8 +156,8 @@ class EjectReplicaSource(tables.BatchAction):
     classes = ('btn-danger', 'btn-eject-replica-source')
 
     def _allowed(self, request, instance=None):
-        return (instance.status != 'PROMOTE'
-                and hasattr(instance, 'replicas'))
+        return (instance.status != 'PROMOTE' and
+                hasattr(instance, 'replicas'))
 
     def action(self, request, obj_id):
         api.trove.eject_replica_source(request, obj_id)
@@ -269,9 +270,9 @@ class ManageAccess(tables.LinkAction):
 
     def get_link_url(self, datum):
         user = datum
-        return urlresolvers.reverse(self.url, args=[user.instance.id,
-                                                    user.name,
-                                                    user.host])
+        return urls.reverse(self.url, args=[user.instance.id,
+                                            user.name,
+                                            user.host])
 
 
 class CreateUser(tables.LinkAction):
@@ -288,7 +289,7 @@ class CreateUser(tables.LinkAction):
 
     def get_link_url(self, datum=None):
         instance_id = self.table.kwargs['instance_id']
-        return urlresolvers.reverse(self.url, args=[instance_id])
+        return urls.reverse(self.url, args=[instance_id])
 
 
 class EditUser(tables.LinkAction):
@@ -305,9 +306,9 @@ class EditUser(tables.LinkAction):
 
     def get_link_url(self, datum):
         user = datum
-        return urlresolvers.reverse(self.url, args=[user.instance.id,
-                                                    user.name,
-                                                    user.host])
+        return urls.reverse(self.url, args=[user.instance.id,
+                                            user.name,
+                                            user.host])
 
 
 def has_user_add_perm(request):
@@ -354,7 +355,7 @@ class CreateDatabase(tables.LinkAction):
 
     def get_link_url(self, datum=None):
         instance_id = self.table.kwargs['instance_id']
-        return urlresolvers.reverse(self.url, args=[instance_id])
+        return urls.reverse(self.url, args=[instance_id])
 
 
 def has_database_add_perm(request):
@@ -410,7 +411,7 @@ class CreateBackup(tables.LinkAction):
                 request.user.has_perm('openstack.services.object-store'))
 
     def get_link_url(self, datam):
-        url = urlresolvers.reverse(self.url)
+        url = urls.reverse(self.url)
         return url + "?instance=%s" % datam.id
 
 
@@ -425,7 +426,7 @@ class ResizeVolume(tables.LinkAction):
 
     def get_link_url(self, datum):
         instance_id = self.table.get_object_id(datum)
-        return urlresolvers.reverse(self.url, args=[instance_id])
+        return urls.reverse(self.url, args=[instance_id])
 
 
 class ResizeInstance(tables.LinkAction):
@@ -435,12 +436,12 @@ class ResizeInstance(tables.LinkAction):
     classes = ("ajax-modal", "btn-resize")
 
     def allowed(self, request, instance=None):
-        return ((instance.status in ACTIVE_STATES
-                 or instance.status == 'SHUTOFF'))
+        return ((instance.status in ACTIVE_STATES or
+                 instance.status == 'SHUTOFF'))
 
     def get_link_url(self, datum):
         instance_id = self.table.get_object_id(datum)
-        return urlresolvers.reverse(self.url, args=[instance_id])
+        return urls.reverse(self.url, args=[instance_id])
 
 
 class AttachConfiguration(tables.LinkAction):
@@ -450,8 +451,8 @@ class AttachConfiguration(tables.LinkAction):
     classes = ("btn-attach-config", "ajax-modal")
 
     def allowed(self, request, instance=None):
-        return (instance.status in ACTIVE_STATES
-                and not hasattr(instance, 'configuration'))
+        return (instance.status in ACTIVE_STATES and
+                not hasattr(instance, 'configuration'))
 
 
 class DetachConfiguration(tables.BatchAction):
@@ -510,7 +511,8 @@ class DisableRootAction(tables.Action):
             messages.success(request, _("Successfully disabled root access."))
         except Exception as e:
             messages.warning(request,
-                             _("Cannot disable root access: %s") % e.message)
+                             _("Cannot disable root access: %s") %
+                             six.text_type(e))
 
 
 class ManageRoot(tables.LinkAction):
@@ -523,7 +525,7 @@ class ManageRoot(tables.LinkAction):
 
     def get_link_url(self, datum=None):
         instance_id = self.table.get_object_id(datum)
-        return urlresolvers.reverse(self.url, args=[instance_id])
+        return urls.reverse(self.url, args=[instance_id])
 
 
 class ManageRootTable(tables.DataTable):
